@@ -15,7 +15,7 @@
 from oslo_log import log
 from osprofiler import profiler
 
-from vitrage.api_handler.apis.base import EntityGraphApisBase
+from vitrage.api_handler.apis import base
 from vitrage.common.constants import HistoryProps as HProps
 from vitrage.common.constants import TenantProps
 from vitrage.common.constants import VertexProperties as VProps
@@ -30,18 +30,14 @@ LOG = log.getLogger(__name__)
 
 @profiler.trace_cls("rca apis",
                     info={}, hide_args=False, trace_private=False)
-class RcaApis(EntityGraphApisBase):
-
-    def __init__(self, entity_graph, conf, db):
-        self.entity_graph = entity_graph
-        self.conf = conf
-        self.db = db
+class RcaApis(base.EntityGraphApisBase):
 
+    @base.lock_graph
     def get_rca(self, ctx, root, all_tenants):
         LOG.debug("RcaApis get_rca - root: %s, all_tenants=%s",
-                  str(root), all_tenants)
+                  root, all_tenants)
 
-        project_id = ctx.get(TenantProps.TENANT, None)
+        project_id = ctx.get(TenantProps.PROJECT_ID, None)
         is_admin_project = ctx.get(TenantProps.IS_ADMIN, False)
 
         if all_tenants:
