@@ -13,14 +13,9 @@
 # under the License.
 
 import abc
-import six
 
 
-@six.add_metaclass(abc.ABCMeta)
-class NotifierBase(object):
-
-    def __init__(self, conf):
-        self.conf = conf
+class NotifierBase(object, metaclass=abc.ABCMeta):
 
     @abc.abstractmethod
     def process_event(self, data, event_type):
