@@ -13,16 +13,10 @@
 # under the License.
 import abc
 
-import six
 
-
-@six.add_metaclass(abc.ABCMeta)
-class SnmpSenderBase(object):
+class SnmpSenderBase(object, metaclass=abc.ABCMeta):
     """Abstract Vitrage snmp trap sender"""
 
-    def __init__(self, conf):
-        self.conf = conf
-
     @abc.abstractmethod
     def send_snmp(self, alarm_data):
         pass
